"use client";
import Image from "next/image";
import iconImg from "@/assets/images/brand/icon.svg";
import BtnPrimary from "@/components/BtnPrimary";
import Link from "next/link";
import SocialLinks from "@/components/SocialLinks";
import { motion } from "framer-motion";
import { usePrivy } from "@privy-io/react-auth";
import { useRouter } from "next/navigation";
import { useEffect } from "react";

export default function Form() {
    const { ready, login, authenticated } = usePrivy();
    const router = useRouter();

    useEffect(() => {
        if (ready && authenticated) {
            router.push("/dashboard/home");
        }
    }, [ready, authenticated, router]);

    if (!ready) {
        return <></>;
    }

    return (
        <motion.div
            initial={{
                y: 50,
                opacity: 0,
            }}
            whileInView={{
                y: 0,
                opacity: 1,
            }}
            viewport={{
                once: true,
            }}
            className="relative w-full max-w-[465px] p-12 border border-white/5 bg-[#0CE77E]/10 backdrop-blur-[1px] flex flex-col items-center"
        >
            <motion.div
                initial={{
                    y: 25,
                    opacity: 0,
                }}
                whileInView={{
                    y: 0,
                    opacity: 1,
                }}
                transition={{
                    delay: 0.2,
                }}
                viewport={{
                    once: true,
                }}
            >
                <Image src={iconImg} alt="icon" width={40} height={40} />
            </motion.div>

            <motion.h1
                initial={{
                    y: 25,
                    opacity: 0,
                }}
                whileInView={{
                    y: 0,
                    opacity: 1,
                }}
                transition={{
                    delay: 0.4,
                }}
                viewport={{
                    once: true,
                }}
                className="mt-7 mb-1 text-[22px] font-medium text-center text-white"
            >
                Welcome to Vertex
            </motion.h1>

            <motion.p
                initial={{
                    y: 25,
                    opacity: 0,
                }}
                whileInView={{
                    y: 0,
                    opacity: 1,
                }}
                transition={{
                    delay: 0.6,
                }}
                viewport={{
                    once: true,
                }}
                className="mb-7 text-lg text-center text-white/50"
            >
                Get access to dashboard
            </motion.p>

            <motion.div
                initial={{
                    y: 25,
                    opacity: 0,
                }}
                whileInView={{
                    y: 0,
                    opacity: 1,
                }}
                transition={{
                    delay: 0.8,
                }}
                viewport={{
                    once: true,
                }}
                className="mb-6 w-full"
            >
                <div onClick={login}>
                    <BtnPrimary text="Sign in" />
                </div>
            </motion.div>

            <motion.p
                initial={{
                    y: 25,
                    opacity: 0,
                }}
                whileInView={{
                    y: 0,
                    opacity: 1,
                }}
                transition={{
                    delay: 1,
                }}
                viewport={{
                    once: true,
                }}
                className="mb-10 text-center text-white"
            >
                By signing up, I agree with Vertex&apos;s{" "}
                <Link href={"/"} className="text-[#0CE77E]">
                    Terms and Conditions
                </Link>{" "}
                &{" "}
                <Link href={"/"} className="text-[#0CE77E]">
                    Privacy Policy
                </Link>
            </motion.p>

            <SocialLinks />

            <span className="absolute -top-px -left-px">
                <svg width="13" height="13" viewBox="0 0 13 13" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M1 1.00037V13.0004" stroke="#0CE77E" strokeWidth="1.5" />
                    <path d="M13 1.00037L1 1.00037" stroke="#0CE77E" strokeWidth="1.5" />
                </svg>
            </span>

            <span className="absolute -bottom-px -left-px">
                <svg width="13" height="13" viewBox="0 0 13 13" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M1 12V-3.57628e-07" stroke="#0CE77E" strokeWidth="1.5" />
                    <path d="M13 12L1 12" stroke="#0CE77E" strokeWidth="1.5" />
                </svg>
            </span>

            <span className="absolute -top-px -right-px">
                <svg width="13" height="13" viewBox="0 0 13 13" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M12 1.00037V13.0004" stroke="#0CE77E" strokeWidth="1.5" />
                    <path d="M0 1.00037L12 1.00037" stroke="#0CE77E" strokeWidth="1.5" />
                </svg>
            </span>

            <span className="absolute -bottom-px -right-px">
                <svg width="13" height="13" viewBox="0 0 13 13" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M12 12V-3.57628e-07" stroke="#0CE77E" strokeWidth="1.5" />
                    <path d="M0 12L12 12" stroke="#0CE77E" strokeWidth="1.5" />
                </svg>
            </span>
        </motion.div>
    );
}
