"use client";
import Image from "next/image";
import nvidiaImg from "@/assets/images/manufacturers/nvidia.svg";
import amdImg from "@/assets/images/manufacturers/amd.svg";
import intelImg from "@/assets/images/manufacturers/intel.svg";
import googleImg from "@/assets/images/manufacturers/google.svg";
import qualcommImg from "@/assets/images/manufacturers/qualcomm.svg";
import Statistics from "./Statistics";
import { motion } from "framer-motion";

export default function BottomBoxes() {
  return (
    <div className="grid grid-cols-2 gap-4">
      <motion.div
        initial={{
          y: 25,
          opacity: 0,
        }}
        whileInView={{
          y: 0,
          opacity: 1,
        }}
        transition={{
          delay: 0.8,
        }}
        viewport={{
          once: true,
        }}
        className="relative p-5 border border-white/5 bg-[#0E1618]/10 backdrop-blur-sm"
      >
        <h3 className="mb-1 font-medium text-[#0CE77E]">
          TOP GPUs BY MANUFACTURER
        </h3>

        <p className="mb-8 text-sm text-white/75">
          A detailed list of GPU manufacturing companies worldwide
        </p>

        <div className="space-y-4">
          <div className="group grid grid-cols-[85px_auto] items-center">
            <Image
              src={nvidiaImg}
              alt=""
              className="opacity-75 group-hover:opacity-100 duration-200"
            />

            <motion.div
              initial={{
                width: "0%",
              }}
              whileInView={{
                width: "100%",
              }}
              transition={{
                delay: 1,
              }}
              viewport={{
                once: true,
              }}
              className="h-[12px] bg-[#0CE77E]"
            ></motion.div>
          </div>

          <div className="group grid grid-cols-[85px_auto] items-center">
            <Image
              src={amdImg}
              alt=""
              className="opacity-75 group-hover:opacity-100 duration-200"
            />

            <motion.div
              initial={{
                width: "0%",
              }}
              whileInView={{
                width: "30%",
              }}
              transition={{
                delay: 1.2,
              }}
              viewport={{
                once: true,
              }}
              className="h-[10px] bg-[#0CE77E]"
            ></motion.div>
          </div>

          <div className="group grid grid-cols-[85px_auto] items-center">
            <Image
              src={intelImg}
              alt=""
              className="opacity-75 group-hover:opacity-100 duration-200"
            />

            <motion.div
              initial={{
                width: "0%",
              }}
              whileInView={{
                width: "20%",
              }}
              transition={{
                delay: 1.4,
              }}
              viewport={{
                once: true,
              }}
              className="h-[10px] bg-[#0CE77E]"
            ></motion.div>
          </div>

          <div className="group grid grid-cols-[85px_auto] items-center">
            <Image
              src={googleImg}
              alt=""
              className="opacity-75 group-hover:opacity-100 duration-200"
            />

            <motion.div
              initial={{
                width: "0%",
              }}
              whileInView={{
                width: "10%",
              }}
              transition={{
                delay: 1.6,
              }}
              viewport={{
                once: true,
              }}
              className="h-[10px] bg-[#0CE77E]"
              style={{
                width: "10%",
              }}
            ></motion.div>
          </div>

          <div className="group grid grid-cols-[85px_auto] items-center">
            <Image
              src={qualcommImg}
              alt=""
              className="opacity-75 group-hover:opacity-100 duration-200"
            />

            <motion.div
              initial={{
                width: "0%",
              }}
              whileInView={{
                width: "5%",
              }}
              transition={{
                delay: 1.8,
              }}
              viewport={{
                once: true,
              }}
              className="h-[10px] bg-[#0CE77E]"
              style={{
                width: "5%",
              }}
            ></motion.div>
          </div>
        </div>

        <span className="absolute -top-px -left-px group-hover:opacity-0 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M1 0V4.5" stroke="#0CE77E" />
            <path d="M5.5 0.5L1 0.5" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -bottom-px -left-px group-hover:opacity-0 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M1 4.5V0" stroke="#0CE77E" />
            <path d="M5.5 4L1 4" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -top-px -right-px group-hover:opacity-0 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M5 0V4.5" stroke="#0CE77E" />
            <path d="M0.5 0.5L5 0.5" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -bottom-px -right-px group-hover:opacity-0 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M5 4.5V0" stroke="#0CE77E" />
            <path d="M0.5 4L5 4" stroke="#0CE77E" />
          </svg>
        </span>
      </motion.div>

      <Statistics />
    </div>
  );
}
