"use client";
import Image from "next/image";
import serverIcon1 from "@/assets/images/server-1-icon.svg";
import serverIcon2 from "@/assets/images/server-2-icon.svg";
import serverIcon3 from "@/assets/images/server-3-icon.svg";
import serverIcon4 from "@/assets/images/server-4-icon.svg";
import { motion } from "framer-motion";

export default function Boxes() {
  return (
    <div className="mb-4 grid grid-cols-4 gap-4">
      <motion.div
        initial={{
          y: 25,
          opacity: 0,
        }}
        whileInView={{
          y: 0,
          opacity: 1,
        }}
        viewport={{
          once: true,
        }}
        className="group relative p-5 border border-white/5 bg-[#0E1618]/10 hover:bg-[#0CE77E]/25 backdrop-blur-sm duration-200"
      >
        <div className="mb-5 flex justify-between items-center">
          <Image src={serverIcon1} alt="" className="w-[40px] h-[40px]" />

          <p className="py-1.5 px-2 border border-[#0CE77E]/10 bg-[#0CE77E]/10 text-xs font-medium text-[#0CE77E]">
            Available
          </p>
        </div>

        <div className="mb-10">
          <h3 className="font-medium text-[#0CE77E]">GAMING GPUs</h3>
          <p className="text-sm text-white/75">Consumer grade GPUs</p>
        </div>

        <div className="relative w-full h-[22px] bg-[#0CE77E]/25">
          <div className="absolute top-0 left-0 w-[31%] h-full px-2 bg-[#0CE77E] flex items-center">
            <p className="text-xs font-semibold text-[#0B1315]">31%</p>
          </div>
        </div>

        <span className="absolute -top-px -left-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M1 0V4.5" stroke="#0CE77E" />
            <path d="M5.5 0.5L1 0.5" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -bottom-px -left-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M1 4.5V0" stroke="#0CE77E" />
            <path d="M5.5 4L1 4" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -top-px -right-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M5 0V4.5" stroke="#0CE77E" />
            <path d="M0.5 0.5L5 0.5" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -bottom-px -right-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M5 4.5V0" stroke="#0CE77E" />
            <path d="M0.5 4L5 4" stroke="#0CE77E" />
          </svg>
        </span>
      </motion.div>

      <motion.div
        initial={{
          y: 25,
          opacity: 0,
        }}
        whileInView={{
          y: 0,
          opacity: 1,
        }}
        transition={{
          delay: 0.2,
        }}
        viewport={{
          once: true,
        }}
        className="group relative p-5 border border-white/5 bg-[#0E1618]/10 hover:bg-[#E2F410]/25 backdrop-blur-sm duration-200"
      >
        <div className="mb-5 flex justify-between items-center">
          <Image src={serverIcon2} alt="" className="w-[40px] h-[40px]" />

          <p className="py-1.5 px-2 border border-[#E2F410]/10 bg-[#E2F410]/10 text-xs font-medium text-[#E2F410]">
            High Performance
          </p>
        </div>

        <div className="mb-10">
          <h3 className="font-medium text-[#E2F410]">Datacenter GPUs</h3>
          <p className="text-sm text-white/75">Datacenter based GPUs</p>
        </div>

        <div className="relative w-full h-[22px] bg-[#E2F410]/25">
          <div className="absolute top-0 left-0 w-[27%] h-full px-2 bg-[#E2F410] flex items-center">
            <p className="text-xs font-semibold text-[#0B1315]">27%</p>
          </div>
        </div>

        <span className="absolute -top-px -left-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M1 0V4.5" stroke="#0CE77E" />
            <path d="M5.5 0.5L1 0.5" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -bottom-px -left-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M1 4.5V0" stroke="#0CE77E" />
            <path d="M5.5 4L1 4" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -top-px -right-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M5 0V4.5" stroke="#0CE77E" />
            <path d="M0.5 0.5L5 0.5" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -bottom-px -right-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M5 4.5V0" stroke="#0CE77E" />
            <path d="M0.5 4L5 4" stroke="#0CE77E" />
          </svg>
        </span>
      </motion.div>

      <motion.div
        initial={{
          y: 25,
          opacity: 0,
        }}
        whileInView={{
          y: 0,
          opacity: 1,
        }}
        transition={{
          delay: 0.4,
        }}
        viewport={{
          once: true,
        }}
        className="group relative p-5 border border-white/5 bg-[#0E1618]/10 hover:bg-[#F65927]/25 backdrop-blur-sm duration-200"
      >
        <div className="mb-5 flex justify-between items-center">
          <Image src={serverIcon3} alt="" className="w-[40px] h-[40px]" />

          <p className="py-1.5 px-2 border border-[#F65927]/10 bg-[#F65927]/10 text-xs font-medium text-[#F65927]">
            Low Performance
          </p>
        </div>

        <div className="mb-10">
          <h3 className="font-medium text-[#F65927]">Integrated GPUs</h3>
          <p className="text-sm text-white/75">Embedded into CPU</p>
        </div>

        <div className="relative w-full h-[22px] bg-[#F65927]/25">
          <div className="absolute top-0 left-0 w-[20%] h-full px-2 bg-[#F65927] flex items-center">
            <p className="text-xs font-semibold text-[#0B1315]">10%</p>
          </div>
        </div>

        <span className="absolute -top-px -left-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M1 0V4.5" stroke="#0CE77E" />
            <path d="M5.5 0.5L1 0.5" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -bottom-px -left-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M1 4.5V0" stroke="#0CE77E" />
            <path d="M5.5 4L1 4" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -top-px -right-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M5 0V4.5" stroke="#0CE77E" />
            <path d="M0.5 0.5L5 0.5" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -bottom-px -right-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M5 4.5V0" stroke="#0CE77E" />
            <path d="M0.5 4L5 4" stroke="#0CE77E" />
          </svg>
        </span>
      </motion.div>

      <motion.div
        initial={{
          y: 25,
          opacity: 0,
        }}
        whileInView={{
          y: 0,
          opacity: 1,
        }}
        transition={{
          delay: 0.6,
        }}
        viewport={{
          once: true,
        }}
        className="group relative p-5 border border-white/5 bg-[#0E1618]/10 hover:bg-[#0CBFE7]/25 backdrop-blur-sm duration-200"
      >
        <div className="mb-5 flex justify-between items-center">
          <Image src={serverIcon4} alt="" className="w-[40px] h-[40px]" />

          <p className="py-1.5 px-2 border border-[#0CBFE7]/10 bg-[#0CBFE7]/10 text-xs font-medium text-[#0CBFE7]">
            Specialised GPU
          </p>
        </div>

        <div className="mb-10">
          <h3 className="font-medium text-[#0CBFE7]">AI GPUs</h3>
          <p className="text-sm text-white/75">Manufactured for AI</p>
        </div>

        <div className="relative w-full h-[22px] bg-[#0CBFE7]/25">
          <div className="absolute top-0 left-0 w-[36%] h-full px-2 bg-[#0CBFE7] flex items-center">
            <p className="text-xs font-semibold text-[#0B1315]">36%</p>
          </div>
        </div>

        <span className="absolute -top-px -left-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M1 0V4.5" stroke="#0CE77E" />
            <path d="M5.5 0.5L1 0.5" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -bottom-px -left-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M1 4.5V0" stroke="#0CE77E" />
            <path d="M5.5 4L1 4" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -top-px -right-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M5 0V4.5" stroke="#0CE77E" />
            <path d="M0.5 0.5L5 0.5" stroke="#0CE77E" />
          </svg>
        </span>

        <span className="absolute -bottom-px -right-px opacity-25 group-hover:opacity-100 duration-200">
          <svg
            width="6"
            height="5"
            viewBox="0 0 6 5"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M5 4.5V0" stroke="#0CE77E" />
            <path d="M0.5 4L5 4" stroke="#0CE77E" />
          </svg>
        </span>
      </motion.div>
    </div>
  );
}
