"use client";
import Image from "next/image";
import iconImg from "@/assets/images/brand/icon.svg";
import Link from "next/link";
import { JSX } from "react/jsx-runtime";
import { usePathname } from "next/navigation";
import { usePrivy } from "@privy-io/react-auth";
import { useState } from "react";

interface ILinksPart {
    title: string;
    links: ILink[];
}

interface ILink {
    icon: JSX.Element;
    title: string;
    href: string;
    subTitle?: string;
    target?: string;
}

export default function Sidebar() {
    const pathname = usePathname();
    const { logout, user } = usePrivy();
    const email = user?.email?.address;
    const discordUsername = user?.discord?.username;
    const address = user?.wallet ? user.wallet.address : "";
    const [copied, setCopied] = useState(false);

    const formatAddress = (address: string | undefined) => {
        if (!address) return "user";
        return `${address.slice(0, 4)}...${address.slice(-5)}`;
    };

    const handleCopyAddress = () => {
        if (address) {
            navigator.clipboard.writeText(address);
            setCopied(true);
            setTimeout(() => {
                setCopied(false);
            }, 2000);
        }
    };

    const linksParts: ILinksPart[] = [
        {
            title: "Dashboard",
            links: [
                {
                    icon: (
                        <svg width="18" height="18" viewBox="0 0 18 18" fill="none" xmlns="http://www.w3.org/2000/svg">
                            <path
                                d="M5.31636 3.57182L4.56635 4.15724C3.42886 5.04511 2.86011 5.48905 2.55505 6.115C2.25 6.74094 2.25 7.46404 2.25 8.91022V10.4786C2.25 13.3172 2.25 14.7364 3.12868 15.6182C4.00736 16.5 5.42157 16.5 8.25 16.5H9.75C12.5784 16.5 13.9927 16.5 14.8713 15.6182C15.75 14.7364 15.75 13.3172 15.75 10.4786V8.91022C15.75 7.46404 15.75 6.74094 15.445 6.115C15.1399 5.48905 14.5712 5.04511 13.4336 4.15724L12.6836 3.57182C10.9141 2.19061 10.0293 1.5 9 1.5C7.9707 1.5 7.0859 2.19061 5.31636 3.57182Z"
                                stroke="#0CE77E"
                                strokeWidth="1.125"
                                strokeLinejoin="round"
                            />
                        </svg>
                    ),
                    title: "Home",
                    href: "/dashboard/home",
                },
                {
                    icon: (
                        <svg width="18" height="18" viewBox="0 0 18 18" fill="none" xmlns="http://www.w3.org/2000/svg">
                            <path
                                d="M6.48223 2.35919L5.20362 2.95021C3.23454 3.86039 2.25 4.31548 2.25 5.0625C2.25 5.80952 3.23454 6.26461 5.20363 7.17478L6.48223 7.7658C7.7214 8.33857 8.34105 8.625 9 8.625C9.65895 8.625 10.2786 8.33857 11.5178 7.7658L12.7964 7.17478C14.7655 6.26461 15.75 5.80952 15.75 5.0625C15.75 4.31548 14.7655 3.86039 12.7964 2.95021L11.5178 2.35919C10.2786 1.7864 9.65895 1.5 9 1.5C8.34105 1.5 7.7214 1.7864 6.48223 2.35919Z"
                                stroke="#0CE77E"
                                strokeWidth="1.125"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                            />
                            <path
                                d="M15.591 8.323C15.697 8.47202 15.75 8.62742 15.75 8.79827C15.75 9.53462 14.7655 9.98327 12.7964 10.8805L11.5178 11.4631C10.2786 12.0277 9.65895 12.3101 9 12.3101C8.34105 12.3101 7.7214 12.0277 6.48223 11.4631L5.20363 10.8805C3.23454 9.98327 2.25 9.53462 2.25 8.79827C2.25 8.62742 2.303 8.47202 2.409 8.323"
                                stroke="#0CE77E"
                                strokeWidth="1.125"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                            />
                            <path
                                d="M15.2825 12.1995C15.5941 12.4477 15.75 12.6951 15.75 12.9881C15.75 13.7245 14.7655 14.1731 12.7964 15.0703L11.5178 15.6529C10.2786 16.2176 9.65895 16.4999 9 16.4999C8.34105 16.4999 7.7214 16.2176 6.48223 15.6529L5.20363 15.0703C3.23454 14.1731 2.25 13.7245 2.25 12.9881C2.25 12.6951 2.40583 12.4477 2.7175 12.1995"
                                stroke="#0CE77E"
                                strokeWidth="1.125"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                            />
                        </svg>
                    ),
                    title: "Rent a GPU",
                    href: "/dashboard/rent",
                },
            ],
        },
        {
            title: "Details",
            links: [
                {
                    icon: (
                        <svg width="18" height="18" viewBox="0 0 18 18" fill="none" xmlns="http://www.w3.org/2000/svg">
                            <path
                                d="M1.875 9C1.875 5.64124 1.875 3.96187 2.91843 2.91843C3.96187 1.875 5.64124 1.875 9 1.875C12.3587 1.875 14.0381 1.875 15.0816 2.91843C16.125 3.96187 16.125 5.64124 16.125 9C16.125 12.3587 16.125 14.0381 15.0816 15.0816C14.0381 16.125 12.3587 16.125 9 16.125C5.64124 16.125 3.96187 16.125 2.91843 15.0816C1.875 14.0381 1.875 12.3587 1.875 9Z"
                                stroke="#0CE77E"
                                strokeWidth="1.125"
                            />
                            <path
                                d="M4.5 10.125L5.625 6.75L7.03125 10.125M4.5 10.125L4.125 11.25M4.5 10.125H7.03125M7.03125 10.125L7.5 11.25"
                                stroke="#0CE77E"
                                strokeWidth="1.125"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                            />
                            <path
                                d="M9.375 9V7.275C9.375 7.1354 9.375 7.06561 9.39337 7.00912C9.43042 6.89495 9.51997 6.80545 9.63412 6.76835C9.6906 6.75 9.76042 6.75 9.9 6.75H10.875C11.4963 6.75 12 7.25368 12 7.875C12 8.4963 11.4963 9 10.875 9H9.375ZM9.375 9V11.25"
                                stroke="#0CE77E"
                                strokeWidth="1.125"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                            />
                            <path
                                d="M13.875 6.75V11.25"
                                stroke="#0CE77E"
                                strokeWidth="1.125"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                            />
                        </svg>
                    ),
                    title: "API & Webhook",
                    href: "/dashboard/api",
                    subTitle: "Q2",
                },
                {
                    icon: (
                        <svg width="18" height="18" viewBox="0 0 18 18" fill="none" xmlns="http://www.w3.org/2000/svg">
                            <path
                                d="M1.5 9C1.5 6.87868 1.5 5.81802 2.15901 5.15901C2.81802 4.5 3.87868 4.5 6 4.5H9.75C11.8713 4.5 12.9319 4.5 13.591 5.15901C14.25 5.81802 14.25 6.87868 14.25 9C14.25 11.1213 14.25 12.1819 13.591 12.841C12.9319 13.5 11.8713 13.5 9.75 13.5H6C3.87868 13.5 2.81802 13.5 2.15901 12.841C1.5 12.1819 1.5 11.1213 1.5 9Z"
                                stroke="#0CE77E"
                                strokeWidth="1.125"
                                strokeLinecap="round"
                            />
                            <path
                                d="M14.25 7.125L15.0204 7.2534C15.5314 7.33856 15.7868 7.38114 15.9807 7.50502C16.1714 7.62682 16.3209 7.8033 16.4097 8.01143C16.5 8.223 16.5 8.48198 16.5 9C16.5 9.51802 16.5 9.777 16.4097 9.98857C16.3209 10.1967 16.1714 10.3732 15.9807 10.495C15.7868 10.6189 15.5314 10.6615 15.0204 10.7466L14.25 10.875"
                                stroke="#0CE77E"
                                strokeWidth="1.125"
                                strokeLinecap="round"
                            />
                            <path d="M4.5 7.5V10.5" stroke="#0CE77E" strokeWidth="1.125" strokeLinecap="round" />
                            <path d="M6.75 7.5V10.5" stroke="#0CE77E" strokeWidth="1.125" strokeLinecap="round" />
                            <path d="M9 7.5V10.5" stroke="#0CE77E" strokeWidth="1.125" strokeLinecap="round" />
                            <path d="M11.25 7.5V10.5" stroke="#0CE77E" strokeWidth="1.125" strokeLinecap="round" />
                        </svg>
                    ),
                    title: "Server Status",
                    href: "/dashboard/server",
                },
            ],
        },
        {
            title: "Support",
            links: [
                {
                    icon: (
                        <svg width="18" height="18" viewBox="0 0 18 18" fill="none" xmlns="http://www.w3.org/2000/svg">
                            <path
                                d="M3.375 7.5C3.375 4.67157 3.375 3.25736 4.25368 2.37868C5.13236 1.5 6.54657 1.5 9.375 1.5H10.5C13.3284 1.5 14.7427 1.5 15.6213 2.37868C16.5 3.25736 16.5 4.67157 16.5 7.5V10.5C16.5 13.3284 16.5 14.7427 15.6213 15.6213C14.7427 16.5 13.3284 16.5 10.5 16.5H9.375C6.54657 16.5 5.13236 16.5 4.25368 15.6213C3.375 14.7427 3.375 13.3284 3.375 10.5V7.5Z"
                                stroke="#0CE77E"
                                strokeWidth="1.125"
                            />
                            <path
                                d="M3.375 4.5H1.5M3.375 9H1.5M3.375 13.5H1.5"
                                stroke="#0CE77E"
                                strokeWidth="1.125"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                            />
                            <path
                                d="M11.4559 6.36958C11.4559 7.19798 10.7844 7.86957 9.95598 7.86957C9.12761 7.86957 8.45605 7.19798 8.45605 6.36958C8.45605 5.54118 9.12761 4.86963 9.95598 4.86963C10.7844 4.86963 11.4559 5.54118 11.4559 6.36958Z"
                                stroke="#0CE77E"
                                strokeWidth="1.125"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                            />
                            <path
                                d="M6.98962 11.7872C7.7834 10.5652 9.04393 10.1073 9.95593 10.1082C10.868 10.1091 12.0916 10.5652 12.8853 11.7872C12.9367 11.8662 12.9508 11.9635 12.9045 12.0456C12.7189 12.3748 12.1425 13.028 11.7262 13.0723C11.2479 13.1232 9.99658 13.1303 9.9569 13.1305C9.91715 13.1303 8.6273 13.1232 8.14873 13.0723C7.73248 13.028 7.1561 12.3748 6.97047 12.0456C6.92416 11.9635 6.9383 11.8662 6.98962 11.7872Z"
                                stroke="#0CE77E"
                                strokeWidth="1.125"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                            />
                        </svg>
                    ),
                    title: "Contact us",
                    href: "/dashboard/contact",
                },
                {
                    icon: (
                        <svg width="18" height="18" viewBox="0 0 18 18" fill="none" xmlns="http://www.w3.org/2000/svg">
                            <path
                                d="M13.107 3H15.0749L10.7757 7.9137L15.8333 14.6001H11.8732L8.77152 10.5449L5.22247 14.6001H3.25342L7.85184 9.34439L3 3H7.06065L9.86431 6.70669L13.107 3ZM12.4163 13.4223H13.5068L6.46815 4.11599H5.29802L12.4163 13.4223Z"
                                fill="#0CE77E"
                            />
                        </svg>
                    ),
                    title: "Twitter/X",
                    href: "https://x.com/vertex_gpu",
                    target: "_blank",
                },
                {
                    icon: (
                        <svg width="18" height="18" viewBox="0 0 18 18" fill="none" xmlns="http://www.w3.org/2000/svg">
                            <path
                                d="M10.5 1.70215V4.80005C10.5 5.22009 10.5 5.43011 10.5818 5.59055C10.6537 5.73167 10.7683 5.8464 10.9095 5.91831C11.0699 6.00005 11.2799 6.00005 11.7 6.00005H14.7979M12 9.75H6M12 12.75H6M7.5 6.75H6M10.5 1.5H6.6C5.33988 1.5 4.70982 1.5 4.22852 1.74524C3.80516 1.96095 3.46095 2.30516 3.24524 2.72852C3 3.20982 3 3.83988 3 5.1V12.9C3 14.1602 3 14.7901 3.24524 15.2715C3.46095 15.6949 3.80516 16.0391 4.22852 16.2548C4.70982 16.5 5.33988 16.5 6.6 16.5H11.4C12.6601 16.5 13.2901 16.5 13.7715 16.2548C14.1949 16.0391 14.5391 15.6949 14.7548 15.2715C15 14.7901 15 14.1602 15 12.9V6L10.5 1.5Z"
                                stroke="#0CE77E"
                                strokeWidth="1.5"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                            />
                        </svg>
                    ),
                    title: "Docs",
                    href: "https://docs.vertexgpu.com",
                    target: "_blank",
                },
            ],
        },
    ];

    return (
        <div className="border border-white/5 bg-[#0E1618] h-full p-5 flex flex-col justify-between">
            <div>
                <div className="pb-5 border-b border-[#0CE77E]/25 flex justify-center">
                    <Link href={"/dashboard/home"}>
                        <Image src={iconImg} alt="" width={32} height={32} />
                    </Link>
                </div>

                {linksParts.map((linksPart, index) => {
                    return (
                        <div key={index} className="mt-7">
                            <p className="mb-4 text-sm uppercase text-white/50">{linksPart.title}</p>

                            <div>
                                {linksPart.links.map((link, linkIndex) => {
                                    return (
                                        <Link
                                            key={linkIndex}
                                            href={link.href}
                                            target={link.target}
                                            className={`relative py-2 px-2.5 border ${
                                                pathname === link.href
                                                    ? "border-white/5 bg-[#0CE77E]/25"
                                                    : "border-transparent"
                                            } flex items-start gap-2.5 text-sm uppercase ${
                                                pathname === link.href ? "text-[#0CE77E]" : "text-white/75"
                                            } hover:text-[#0CE77E] duration-200`}
                                        >
                                            {link.icon}
                                            {link.title}

                                            {link.subTitle && (
                                                <span className="absolute top-1/2 right-2.5 -translate-y-1/2">
                                                    {link.subTitle}
                                                </span>
                                            )}

                                            {pathname === link.href && (
                                                <>
                                                    <span className="absolute -top-px -left-px group-hover:opacity-0 duration-200">
                                                        <svg
                                                            width="6"
                                                            height="5"
                                                            viewBox="0 0 6 5"
                                                            fill="none"
                                                            xmlns="http://www.w3.org/2000/svg"
                                                        >
                                                            <path d="M1 0V4.5" stroke="#0CE77E" />
                                                            <path d="M5.5 0.5L1 0.5" stroke="#0CE77E" />
                                                        </svg>
                                                    </span>

                                                    <span className="absolute -bottom-px -left-px group-hover:opacity-0 duration-200">
                                                        <svg
                                                            width="6"
                                                            height="5"
                                                            viewBox="0 0 6 5"
                                                            fill="none"
                                                            xmlns="http://www.w3.org/2000/svg"
                                                        >
                                                            <path d="M1 4.5V0" stroke="#0CE77E" />
                                                            <path d="M5.5 4L1 4" stroke="#0CE77E" />
                                                        </svg>
                                                    </span>

                                                    <span className="absolute -top-px -right-px group-hover:opacity-0 duration-200">
                                                        <svg
                                                            width="6"
                                                            height="5"
                                                            viewBox="0 0 6 5"
                                                            fill="none"
                                                            xmlns="http://www.w3.org/2000/svg"
                                                        >
                                                            <path d="M5 0V4.5" stroke="#0CE77E" />
                                                            <path d="M0.5 0.5L5 0.5" stroke="#0CE77E" />
                                                        </svg>
                                                    </span>

                                                    <span className="absolute -bottom-px -right-px group-hover:opacity-0 duration-200">
                                                        <svg
                                                            width="6"
                                                            height="5"
                                                            viewBox="0 0 6 5"
                                                            fill="none"
                                                            xmlns="http://www.w3.org/2000/svg"
                                                        >
                                                            <path d="M5 4.5V0" stroke="#0CE77E" />
                                                            <path d="M0.5 4L5 4" stroke="#0CE77E" />
                                                        </svg>
                                                    </span>
                                                </>
                                            )}
                                        </Link>
                                    );
                                })}
                            </div>
                        </div>
                    );
                })}
            </div>

            <div className="flex justify-between items-center">
                <div className="flex items-center gap-2.5">
                    <svg width="18" height="18" viewBox="0 0 18 18" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path
                            d="M12 10.5C12 11.1213 12.5037 11.625 13.125 11.625C13.7463 11.625 14.25 11.1213 14.25 10.5C14.25 9.8787 13.7463 9.375 13.125 9.375C12.5037 9.375 12 9.8787 12 10.5Z"
                            stroke="#0CE77E"
                            strokeWidth="1.125"
                        />
                        <path
                            d="M7.5 5.25H12C14.1213 5.25 15.1819 5.25 15.841 5.90901C16.5 6.56802 16.5 7.6287 16.5 9.75V11.25C16.5 13.3713 16.5 14.4319 15.841 15.091C15.1819 15.75 14.1213 15.75 12 15.75H7.5C4.67157 15.75 3.25736 15.75 2.37868 14.8713C1.5 13.9927 1.5 12.5784 1.5 9.75V8.25C1.5 5.42157 1.5 4.00736 2.37868 3.12868C3.25736 2.25 4.67157 2.25 7.5 2.25H10.5C11.1975 2.25 11.5462 2.25 11.8324 2.32667C12.6088 2.53472 13.2153 3.1412 13.4234 3.91765C13.5 4.20378 13.5 4.55252 13.5 5.25"
                            stroke="#0CE77E"
                            strokeWidth="1.125"
                            strokeLinecap="round"
                        />
                    </svg>

                    <div className="flex flex-col">
                        {email && <span className="text-sm font-medium text-white">{email.split("@")[0]}</span>}
                        {discordUsername && !email && (
                            <span className="text-sm font-medium text-white">{discordUsername}</span>
                        )}
                        {address && !email && !discordUsername && (
                            <button
                                onClick={handleCopyAddress}
                                className="text-sm font-medium text-white hover:text-[#0CE77E] transition-colors duration-200"
                            >
                                {copied ? "Copied!" : formatAddress(address)}
                            </button>
                        )}
                    </div>
                </div>

                <div className="group relative">
                    <button className="flex">
                        <svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                            <g opacity="0.8">
                                <path
                                    d="M6 10.5C5.17157 10.5 4.5 11.1716 4.5 12C4.5 12.8284 5.17157 13.5 6 13.5C6.82843 13.5 7.5 12.8284 7.5 12C7.5 11.1716 6.82843 10.5 6 10.5Z"
                                    fill="white"
                                />
                                <path
                                    d="M10.5 12C10.5 11.1716 11.1716 10.5 12 10.5C12.8284 10.5 13.5 11.1716 13.5 12C13.5 12.8284 12.8284 13.5 12 13.5C11.1716 13.5 10.5 12.8284 10.5 12Z"
                                    fill="white"
                                />
                                <path
                                    d="M16.5 12C16.5 11.1716 17.1716 10.5 18 10.5C18.8284 10.5 19.5 11.1716 19.5 12C19.5 12.8284 18.8284 13.5 18 13.5C17.1716 13.5 16.5 12.8284 16.5 12Z"
                                    fill="white"
                                />
                            </g>
                        </svg>
                    </button>

                    <div className="absolute bottom-full right-0 pb-2 opacity-0 group-focus-within:opacity-100 pointer-events-none group-focus-within:pointer-events-auto duration-200">
                        <button
                            onClick={logout}
                            className="py-1.5 px-2 border border-white/5 bg-[#0E1618] flex items-center gap-2 text-sm whitespace-nowrap text-white"
                        >
                            <svg
                                width="16"
                                height="16"
                                viewBox="0 0 16 16"
                                fill="none"
                                xmlns="http://www.w3.org/2000/svg"
                                className="w-[16px] min-w-[16px]"
                            >
                                <path
                                    d="M9.33333 2.06335C9.02867 2.02161 8.717 2 8.4 2C4.86538 2 2 4.68629 2 8C2 11.3137 4.86538 14 8.4 14C8.717 14 9.02867 13.9784 9.33333 13.9367"
                                    stroke="#E7400C"
                                    strokeLinecap="round"
                                />
                                <path
                                    d="M14.0002 8.00004H7.3335M14.0002 8.00004C14.0002 7.53324 12.6706 6.66106 12.3335 6.33337M14.0002 8.00004C14.0002 8.46684 12.6706 9.33904 12.3335 9.66671"
                                    stroke="#E7400C"
                                    strokeLinecap="round"
                                    strokeLinejoin="round"
                                />
                            </svg>
                            Log out
                        </button>
                    </div>
                </div>
            </div>
        </div>
    );
}
